biodata-package: biodata: Example datasets and analyses from the life...

Description Author(s)

Description

biodata is a repository of datasets from throughout the life sciences which can be used for demonstrating, exploring, and learning data science, statistic, and machine learning.

Author(s)

Maintainer: Nathan Brouwer brouwernt@gmail.com


brouwern/biodata documentation built on Dec. 31, 2020, 8:58 p.m.