biodata is a repository of datasets from throughout the life sciences which can be used for demonstrating, exploring, and learning data science, statistic, and machine learning.
Maintainer: Nathan Brouwer brouwernt@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.